==> haskell-lsp0-0.24.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lsp
version:              0.24.0.0
visibility:           public
id:                   haskell-lsp-0.24.0.0-60OyPVZWpcmJeJUNkJ8NUx
key:                  haskell-lsp-0.24.0.0-60OyPVZWpcmJeJUNkJ8NUx
license:              MIT
copyright:            Alan Zimmerman, 2016-2020
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/haskell-lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell IDE
    Engine, at https://github.com/haskell/haskell-ide-engine

category:             Development
abi:                  28ca41c5be64c9a7b0248e4a982c458b
exposed:              True
exposed-modules:
    Language.Haskell.LSP.Capture, Language.Haskell.LSP.Constant,
    Language.Haskell.LSP.Control, Language.Haskell.LSP.Core,
    Language.Haskell.LSP.Diagnostics, Language.Haskell.LSP.Messages,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa:Language.Haskell.LSP.Types.Capabilities,
    Language.Haskell.LSP.Types.Lens from haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa:Language.Haskell.LSP.Types.Lens,
    Language.Haskell.LSP.Utility, Language.Haskell.LSP.VFS

import-dirs:          /usr/lib/ghc-8.10.5/site-local/haskell-lsp-0.24.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/haskell-lsp-0.24.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/haskell-lsp-0.24.0.0
hs-libraries:         HShaskell-lsp-0.24.0.0-60OyPVZWpcmJeJUNkJ8NUx
depends:
    aeson-1.5.6.0-6uunGgFAYkLL5zoDUTK2GY
    async-2.2.3-HtWYxLW2ntnKBaQHYE7IJT
    attoparsec-0.14.1-qO4BENHL0SHN8QdgrNcG6 base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1
    data-default-0.7.1.1-1PvF2urvLxF7Pa94frLNmw directory-1.3.6.0
    filepath-1.4.2.1 hashable-1.3.2.0-IDkVQhKLyXDF7itJntNZ2M
    haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa
    hslogger-1.3.1.0-3ObpHgfbfIE1eZU1DZuCrC
    lens-5.0.1-35rFO49duny9UmEBJRCnDB mtl-2.2.2
    network-uri-2.6.4.1-AJEy95J8Z3N4HoBtLbmjVO
    rope-utf16-splay-0.3.2.0-H9FJ0YWNyLk204FZMOmAex
    sorted-list-0.2.1.0-9nmT4tHEEdz1Ro1gJtKttX stm-2.5.0.1
    temporary-1.3-BDoGPG2fF5P3MQeO1JQscK text-1.2.4.1 time-1.9.3
    unordered-containers-0.2.14.0-1OFWlQlrCvvLaIazZ0Uw3i

haddock-interfaces:   /usr/share/doc/haskell-lsp0/html/haskell-lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp0/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp0-0.24.0.0-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lsp
version:              0.24.0.0
visibility:           public
id:                   haskell-lsp-0.24.0.0-1nLmsIlKwjELkiqa3hAksX
key:                  haskell-lsp-0.24.0.0-1nLmsIlKwjELkiqa3hAksX
license:              MIT
copyright:            Alan Zimmerman, 2016-2020
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/haskell-lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell IDE
    Engine, at https://github.com/haskell/haskell-ide-engine

category:             Development
abi:                  fbac5627f019bde8935c7a908b351a7a
exposed:              True
exposed-modules:
    Language.Haskell.LSP.Capture, Language.Haskell.LSP.Constant,
    Language.Haskell.LSP.Control, Language.Haskell.LSP.Core,
    Language.Haskell.LSP.Diagnostics, Language.Haskell.LSP.Messages,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa:Language.Haskell.LSP.Types.Capabilities,
    Language.Haskell.LSP.Types.Lens from haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa:Language.Haskell.LSP.Types.Lens,
    Language.Haskell.LSP.Utility, Language.Haskell.LSP.VFS

import-dirs:          /usr/lib/ghc-8.10.5/site-local/haskell-lsp-0.24.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/haskell-lsp-0.24.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/haskell-lsp-0.24.0.0
hs-libraries:         HShaskell-lsp-0.24.0.0-1nLmsIlKwjELkiqa3hAksX
depends:
    aeson-1.5.6.0-6uunGgFAYkLL5zoDUTK2GY
    async-2.2.3-HtWYxLW2ntnKBaQHYE7IJT
    attoparsec-0.14.1-qO4BENHL0SHN8QdgrNcG6 base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1
    data-default-0.7.1.1-1PvF2urvLxF7Pa94frLNmw directory-1.3.6.0
    filepath-1.4.2.1 hashable-1.3.2.0-IDkVQhKLyXDF7itJntNZ2M
    haskell-lsp-types-0.24.0.0-Gw50OfwGrs2CnlszbWQaIa
    hslogger-1.3.1.0-JJq8ZbgmQqy1x1DwsQpluT
    lens-5.0.1-35rFO49duny9UmEBJRCnDB mtl-2.2.2
    network-uri-2.6.4.1-AJEy95J8Z3N4HoBtLbmjVO
    rope-utf16-splay-0.3.2.0-H9FJ0YWNyLk204FZMOmAex
    sorted-list-0.2.1.0-9nmT4tHEEdz1Ro1gJtKttX stm-2.5.0.1
    temporary-1.3-BDoGPG2fF5P3MQeO1JQscK text-1.2.4.1 time-1.9.3
    unordered-containers-0.2.14.0-1OFWlQlrCvvLaIazZ0Uw3i

haddock-interfaces:   /usr/share/doc/haskell-lsp0/html/haskell-lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp0/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
